



def clique ():
	import click
	@click.group ("mints")
	def group ():
		pass


	'''
		crowns mints list-the-names
	'''
	import click
	@group.command ("list-the-names")
	def names ():
		import crowns.mints.names as mints_names
		mints_names = mints_names.start ()
	
		for name in mints_names:
			print (name)
	
		return;

	'''
		crowns mints save --name "mint-1"
	'''
	import click
	@group.command ("save")
	@click.option ('--name', required = True)
	def search (name):
		print ("name:", name)
	
		print ('not yet implemented')
	
		return;

	return group




#







import pathlib
import inspect
import os
from os.path import dirname, join, normpath

from crowns.clique import clique
import crowns.config.scan as config_scan
import crowns.climate as crowns_climate



print ("crowns @:", pathlib.Path (__file__).parent.resolve ())



configured = False

def is_configured ():
	return configured

def start ():
	crowns_config = config_scan.start ()
	if (crowns_config == False): 
		return;

	print ('crowns configuration', crowns_config.configuration)
	
	
	'''
		get the absolute paths
	'''
	crowns_config.configuration ["treasuries"] ["path"] = (
		normpath (join (
			crowns_config.directory_path, 
			crowns_config.configuration ["treasuries"] ["path"]
		))
	)
	crowns_config.configuration ["mints"] ["path"] = (
		normpath (join (
			crowns_config.directory_path, 
			crowns_config.configuration ["mints"] ["path"]
		))
	)

	#print ('crowns configuration', crowns_config.configuration)

	'''
		Add the changed version of the basal config
		to the climate.
	'''
	config = crowns_config.configuration;
	for field in config: 
		crowns_climate.change (field, config [field])
	
	configured = True
	
	print ()





'''
	import crowns.climate as crowns_climate
	crowns_climate.change ("treasuries", {
		"path": treasuries_path
	})

	import crowns.climate as crowns_climate
	climate_treasuries = crowns_climate.find ("treasuries")
	climate_mints = crowns_climate.find ("mints")


	print ('climate_treasuries', climate_treasuries)
	print ('climate_mints', climate_mints)
'''

import copy

climate = {}

def change (field, plant):
	#global CLIMATE;
	climate [ field ] = plant


def find (field):
	#print ("climate:", climate)

	return copy.deepcopy (climate) [ field ]